@@ -4,5 +4,5 @@ register = template.Library()
 from ..helpers import decimal_hours as dh
 
 @register.filter(name='decimal_hours')
-def decimal_hours(value):
-    return dh(value)
\ No newline at end of file
+def decimal_hours(value, decimal_places=None):
+    return dh(value, decimal_places)
\ No newline at end of file
